@@ -2,6 +2,7 @@ import copy
 import datetime
 import io
 import os
+import pickle
 import tempfile
 import unittest
 from pathlib import Path
@@ -20,7 +21,7 @@ from huggingface_hub.hf_file_system import (
 )
 
 from .testing_constants import ENDPOINT_STAGING, TOKEN
-from .testing_utils import repo_name, with_production_testing
+from .testing_utils import OfflineSimulationMode, offline, repo_name, with_production_testing
 
 
 class HfFileSystemTests(unittest.TestCase):
@@ -486,6 +487,20 @@ class HfFileSystemTests(unittest.TestCase):
             self.hffs.get_file(self.hf_path + "/data", temp_dir + "/data")
             assert (Path(temp_dir) / "data").exists()
 
+    def test_pickle(self):
+        # Test that pickling re-populates the HfFileSystem cache and keeps the instance cache attributes
+        fs = HfFileSystem()
+        fs.isfile(self.text_file)
+        pickled = pickle.dumps(fs)
+        HfFileSystem.clear_instance_cache()
+        with offline(mode=OfflineSimulationMode.CONNECTION_FAILS):
+            fs = pickle.loads(pickled)
+            assert isinstance(fs, HfFileSystem)
+            assert fs in HfFileSystem._cache.values()
+            assert self.hf_path + "/data" in fs.dircache
+            assert list(fs._repo_and_revision_exists_cache)[0][1] == self.repo_id
+            assert fs.isfile(self.text_file)
+
 
 @pytest.mark.parametrize("path_in_repo", ["", "file.txt", "path/to/file"])
 @pytest.mark.parametrize(
